NAME
Map::Tube::CLI - Command Line Interface for Map::Tube::* map.
VERSION
Version v0.850.0
DESCRIPTION
This module provides a simple command line interface to the package consuming Map::Tube. The distribution also contains a script map-tube for use at the command line which uses this package.
SYNOPSIS
You can list all command line options by giving the -h flag.
$ map-tube -h
USAGE: map-tube [-h] [options...]
-m --map=String Map name
-s --start=String Start station name
-e --end=String End station name
-p --preferred Show preferred route
-g --generate_map Generate map as image
-l --line=String Line name to map
-b --bgcolor=String Map background color
--line_mappings Generate line mappings as table
--line_notes Generate line notes
-M --list_maps List supported maps
-L --list_lines List lines in given map
-S --list_stations List stations in given map
-t --tabular Show route as table (not as list)
-f --force Force unsupported map (map name becomes case sensitive)
-D --debug Run in debug mode
-V --version Show version information
--usage show a short help message
-h show a compact help message
--help show a long help message
--man show the manual
COMMON USAGES
Shortest Route
You can ask for the shortest route in the London Tube Map as below: (Under Windows use double quotes.)
$ map-tube --map London --start 'Baker Street' --end 'Wembley Park'
Baker Street (Bakerloo, Circle, Hammersmith & City, Jubilee, Metropolitan), Finchley Road (Jubilee, Metropolitan), Wembley Park (Jubilee, Metropolitan)
Preferred Shortest Route
Now a request for the preferred route:
$ map-tube --map London --start 'Baker Street' --end 'Euston Square' --preferred
Baker Street (Circle, Hammersmith & City, Metropolitan), Great Portland Street (Circle, Hammersmith & City, Metropolitan), Euston Square (Circle, Hammersmith & City, Metropolitan)
Preferred Shortest Route in Tabular Form
And a request for the preferred route displayed as a table: (This also shows the use of short options.)
$ map-tube -m London -s 'Baker Street' -e 'Euston Square' -p -t
Metro Map London: Route from Baker Street to Euston Square.
.--------------------------------------------------------------------.
| Station Name | Lines |
+-----------------------+--------------------------------------------+
| Baker Street | Circle, Hammersmith and City, Metropolitan |
| Great Portland Street | Circle, Hammersmith and City, Metropolitan |
| Euston Square | Circle, Hammersmith and City, Metropolitan |
'-----------------------+--------------------------------------------'
Baker Street (Circle, Hammersmith & City, Metropolitan), Great Portland Street (Circle, Hammersmith & City, Metropolitan), Euston Square (Circle, Hammersmith & City, Metropolitan)
Generate Full Map
To generate a graphical representation of the entire map, follow the command below. This will generate a PNG file named after the map in your current working directory. (It will silently overwrite any pre-existing file of the same name.)
$ map-tube --map Delhi --generate_map
In case you want a different background color to the map then you can try this:
$ map-tube --map Delhi --bgcolor gray --generate_map
Generate Just a Line Map
To generate a graphical representation of just a particular line, follow the command below. This will generate a PNG file named after the line in your current working directory. (It will silently overwrite any pre-existing file of the same name.)
$ map-tube --map London --line Bakerloo --generate_map
In case you want a different background color to the map then you can try this:
$ map-tube --map London --line DLR --bgcolor yellow --generate_map
Generate Line Mappings as a Table
$ map-tube --map London --line Bakerloo --line_mappings
Generate Line Notes
$ map-tube --map London --line Bakerloo --line_notes
List the Lines for the Given Map
$ map-tube --map London --list_lines
List the Stations for the Given Map
$ map-tube --map London --list_stations
List all Supported Maps
This will show you a list of all officially supported maps. It will also show you which of these maps are not currently installed on your machine.
$ map-tube --list_maps
Using a Map that is Not Officially Supported
It is also possible to use tube maps that are not officially supported, e.g., privately created maps: (This is also helpful while developing a new map.)
$ map-tube --map 'Slippery Rock' --start 'College Park' --end 'Greyhound station' --force
General Error
If encountering an invalid map or a missing map (i.e not installed), you get an error message like below:
$ map-tube --map xYz --start 'Baker Street' --end 'Euston Square'
ERROR: Unsupported Map [xYz].
This will produce a similar message if you do not have the tube map of Kazan installed; if you do have it, it will notify you that the starting station does not exist in this map:
$ map-tube --map Kazan --start 'Baker Street' --end 'Euston Square'
ERROR: Missing Map [Kazan].
SUPPORTED MAPS
The command line parameter map can take one of the following map names. It is case insensitive, i.e. 'London' and 'lOndOn' are the same. Use the --list_maps option describe above to get an up-to-date version of this list. Use the --force option described above to use locally installed maps that are not on that list.
You could use Task::Map::Tube::Bundle to install the supported maps. Please make sure you have the latest maps when you install.
METHODS
run()
This is the only method provided by the package Map::Tube::CLI. It does not expect any parameter. Here is the code from the supplied map-tube script.
use strict; use warnings;
use Map::Tube::CLI;
Map::Tube::CLI->new_with_options->run;
AUTHOR
Mohammad Sajid Anwar, <mohammad.anwar at yahoo.com>
REPOSITORY
https://github.com/manwar/Map-Tube-CLI
BUGS
Please report any bugs or feature requests through the web interface at https://github.com/manwar/Map-Tube-CLI/issues. I will be notified and then you'll automatically be notified of progress on your bug as I make changes.
SUPPORT
You can find documentation for this module with the perldoc command.
perldoc Map::Tube::CLI
You can also look for information at:
BUG Report
CPAN Ratings
Search MetaCPAN
LICENSE AND COPYRIGHT
Copyright (C) 2015 - 2026 Mohammad Sajid Anwar.
This program is free software; you can redistribute it and / or modify it under the terms of the the Artistic License (2.0). You may obtain a copy of the full license at:
http://www.perlfoundation.org/artistic_license_2_0
Any use, modification, and distribution of the Standard or Modified Versions is governed by this Artistic License.By using, modifying or distributing the Package, you accept this license. Do not use, modify, or distribute the Package, if you do not accept this license.
If your Modified Version has been derived from a Modified Version made by someone other than you,you are nevertheless required to ensure that your Modified Version complies with the requirements of this license.
This license does not grant you the right to use any trademark, service mark, tradename, or logo of the Copyright Holder.
This license includes the non-exclusive, worldwide, free-of-charge patent license to make, have made, use, offer to sell, sell, import and otherwise transfer the Package with respect to any patent claims licensable by the Copyright Holder that are necessarily infringed by the Package. If you institute patent litigation (including a cross-claim or counterclaim) against any party alleging that the Package constitutes direct or contributory patent infringement,then this Artistic License to you shall terminate on the date that such litigation is filed.
Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER AND CONTRIBUTORS "AS IS' AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES. THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, OR NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.